%% Visualize data of the IAS-Lab RGBD-ID Dataset from the chosen person and from training or testing sets %%
% It supposes the folder structure to be the following:
%   base_dir -> Training -> 000 
%                           ... 
%                           010
%            -> TestingA -> 000 
%                           ... 
%                           010
%            -> TestingB -> 000 
%                           ... 
%                           010
%
% If you use this dataset, please cite:
% M. Munaro, S. Ghidoni, D. Tartaro Dizmen and E. Menegatti. 
% A feature-based approach to people re-identification using skeleton keypoints. 
% In Proceedings of IEEE International Conference on Robotics and Automation (ICRA), Hong Kong (China), 2014.
%
% L. Nanni, M. Munaro, S. Ghidoni, E. Menegatti, S. Brahnam. 
% Ensemble of Different Approaches for a Reliable Person Re-identification System. 
% Journal on Applied Computing and Informatics, ISSN: 2210-8327, 2015.
%
% Author: Matteo Munaro
% Date: 27th July 2013

addpath(pwd)
clc; clear all; close all;

%% Parameters to choose:
base_dir = uigetdir(pwd); % select path to the main folder (containing 'Training', 'TestingA' and 'TestingB')
dataset = 0;  % 0: Training set, 1: TestingA (different clothes wrt Training), 2: TestingB (same clothes as in Training);
person_number = 0;  % person to be visualized (ranges between 0 and 10)

%% Check parameters:
number_string = num2str(person_number, '%03d');
if (dataset == 0)
    data_dir = [base_dir '/Training/' number_string];
else if (dataset == 1)
        data_dir = [base_dir '/TestingA/' number_string];
    else if (dataset == 2)
        data_dir = [base_dir '/TestingB/' number_string];
        else
            display('ERROR: not valid ''dataset'' value!')
            return;
        end
    end
end

%% Read filenames:
if ~exist(data_dir, 'dir'); % if the data directory does not exist
    display('ERROR: the chosen person is not present in the chosen dataset.');
    return;
end

cd(data_dir)
rgb_files = dir('*b.jpg');
usermap_files = dir('*p.pgm');
depth_files = dir('*h.pgm');
skeleton_files = dir('*l.txt');

% Parameters for skeleton visualization:
line_width = 3;
scale_factor_skelToImage = 1;
plot_only_tracked_joints = true;

% Read and display ground coefficients:
ground = dlmread('ground_coeffs.txt');
if (sum(abs(ground)) > 0)
    disp(ground);
end
   
%% Main loop:
h = figure;
set(h,'Position',[0 0 2600 480]);
for i = 1:size(rgb_files,1)
   clf;
     
   % Visualize rgb image:
   subplot(1,3,1);
   imshow(imread(rgb_files(i).name));
   
   % Visualize depth image:
   subplot(1,3,2);
   imagesc(imread(depth_files(i).name));
   
   % Visualize user map:
   subplot(1,3,3);
   imagesc(imread(usermap_files(i).name));
   
   % Plot skeleton on the depth image:
   Pos = dlmread(skeleton_files(i).name);   
   if Pos(1,1) > 0  % if there is a skeleton
       subplot(1,3,1);
       plotSkeleton2D(Pos(1:20,:), 0, line_width, false, scale_factor_skelToImage, plot_only_tracked_joints);
   end
   
   pause(eps);
end

